@@ -1,4 +1,4 @@
-/* $Id: sqlite_callbacks.c,v 1.14 2012/05/28 07:53:25 imilh Exp $ */
+/* $Id: sqlite_callbacks.c,v 1.15 2012/07/15 17:36:34 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010, 2011, 2012 The NetBSD Foundation, Inc.
@@ -39,7 +39,7 @@ int
 pdb_rec_list(void *param, int argc, char **argv, char **colname)
 {
 	Pkglist	   	*plist;
-	Plisthead 	*plisthead = (Plisthead *)param;
+	Plistnumbered	*plisthead = (Plistnumbered *)param;
 	int			i;
 
 	if (argv == NULL)
@@ -80,7 +80,8 @@ pdb_rec_list(void *param, int argc, char **argv, char **colname)
 			plist->file_size = strtol(argv[i], (char **)NULL, 10);
 	}
 
-	SLIST_INSERT_HEAD(plisthead, plist, next);
+	SLIST_INSERT_HEAD(plisthead->P_Plisthead, plist, next);
+	plisthead->P_count++;
 
 	return PDB_OK;
 }
